==> iotivity-1.0.0.tar.gz: iotivity-1.0.0/android/android_api/base/jni/JniProvisionResultListner.h <==
/*
* //******************************************************************
* //
* // Copyright 2015 Samsung Electronics All Rights Reserved.
* //
* //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
* //
* // Licensed under the Apache License, Version 2.0 (the "License");
* // you may not use this file except in compliance with the License.
* // You may obtain a copy of the License at
* //
* //      http://www.apache.org/licenses/LICENSE-2.0
* //
* // Unless required by applicable law or agreed to in writing, software
* // distributed under the License is distributed on an "AS IS" BASIS,
* // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* // See the License for the specific language governing permissions and
* // limitations under the License.
* //
* //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/
#include <jni.h>
#include "JniOcStack.h"
#include "OCProvisioningManager.h"

#ifndef _Included_org_iotivity_base_OcProvisioning_JniProvisionResultListner
#define _Included_org_iotivity_base_OcProvisioning_JniProvisionResultListner

typedef std::function<void(JNIEnv* env, jobject jListener)> RemoveCallback;

enum class ListenerFunc
{
    OWNERSHIPTRANSFER = 1,
    PROVISIONACL,
    PROVISIONCREDENTIALS,
    UNLINKDEVICES,
    REMOVEDEVICE,
    PROVISIONPAIRWISEDEVICES
};

class JniProvisionResultListner
{
    public:
        JniProvisionResultListner(JNIEnv *env, jobject jListener,
                RemoveCallback removeProvisionResultListener);
        ~JniProvisionResultListner();

        void ProvisionResultCallback(OC::PMResultList_t *result, int hasError, ListenerFunc func);

    private:
        RemoveCallback m_removeProvisionResultListener;
        jweak m_jwListener;
        void checkExAndRemoveListener(JNIEnv* env);
};
#endif

==> iotivity-1.2.1.tar.gz: iotivity-1.2.1/android/android_api/base/jni/JniProvisionResultListner.h <==
/*
* //******************************************************************
* //
* // Copyright 2015 Samsung Electronics All Rights Reserved.
* //
* //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
* //
* // Licensed under the Apache License, Version 2.0 (the "License");
* // you may not use this file except in compliance with the License.
* // You may obtain a copy of the License at
* //
* //      http://www.apache.org/licenses/LICENSE-2.0
* //
* // Unless required by applicable law or agreed to in writing, software
* // distributed under the License is distributed on an "AS IS" BASIS,
* // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* // See the License for the specific language governing permissions and
* // limitations under the License.
* //
* //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/
#include <jni.h>
#include "JniOcStack.h"
#include "OCProvisioningManager.hpp"

#ifndef _Included_org_iotivity_base_OcProvisioning_JniProvisionResultListner
#define _Included_org_iotivity_base_OcProvisioning_JniProvisionResultListner

typedef std::function<void(JNIEnv* env, jobject jListener)> RemoveCallback;

enum class ListenerFunc
{
    OWNERSHIPTRANSFER = 1,
    PROVISIONACL,
    PROVISIONCREDENTIALS,
    PROVISIONTRUSTCERTCHAIN,
    UNLINKDEVICES,
    REMOVEDEVICE,
    PROVISIONPAIRWISEDEVICES,
    PROVISIONDIRECTPAIRING
};

class JniProvisionResultListner
{
    public:
        JniProvisionResultListner(JNIEnv *env, jobject jListener,
                RemoveCallback removeProvisionResultListener);
        ~JniProvisionResultListner();

        void ProvisionResultCallback(OC::PMResultList_t *result, int hasError, ListenerFunc func);

    private:
        RemoveCallback m_removeProvisionResultListener;
        jweak m_jwListener;
        void checkExAndRemoveListener(JNIEnv* env);
};
#endif
